@@ -2,6 +2,7 @@
 function (groups, side, beanlines, beanlinewd, at, boxwex, n, 
     col, horizontal, mlog, mexp) 
 {
+	res = NULL
     if (side == 4) 
         at <- rep(at, each = 2)
     for (i in 1:n) {
@@ -14,6 +15,7 @@ function (groups, side, beanlines, beanlinewd, at, boxwex, n,
         else {
             quants <- mexp(mean(mlog(groups[[i]])))
         }
+		res = c(res, quants)
         x1 <- if (side == 3 || ((side == 4) && (i%%2 == 0))) 
             at[i]
         else at[i] - boxwex/2
@@ -26,5 +28,6 @@ function (groups, side, beanlines, beanlinewd, at, boxwex, n,
         else segments(x1, quants, x2, quants, lwd = beanlinewd, 
             col = col[[i]][4])
     }
+	res
 }
 
